pub struct SchedulerConfig {
pub policy: SchedulePolicy,
pub clock: ClockMode,
pub default_channel_capacity: usize,
pub preempt_every: u32,
pub workers: usize,
}Expand description
All scheduler knobs, bundled. Has a Default and fluent setters so it is easy
to annotate while still having a sensible baseline.
Fields
policy: SchedulePolicyReady-task selection discipline (default Fifo).
clock: ClockModeClock mode (default Logical).
default_channel_capacity: usizeDefault capacity for channels created without an explicit one
(default 32 — matches the AOT mpsc default).
preempt_every: u32Cooperative yield interval, in scheduler steps (default 10_000).
workers: usizeM:N worker count; 1 = cooperative single-thread (default 1).
Implementations
Sourceimpl SchedulerConfig
impl SchedulerConfig
Sourcepub fn with_policy(self, policy: SchedulePolicy) -> Self
pub fn with_policy(self, policy: SchedulePolicy) -> Self
Set the scheduling policy.
Sourcepub fn with_clock(self, clock: ClockMode) -> Self
pub fn with_clock(self, clock: ClockMode) -> Self
Set the clock mode.
Sourcepub fn with_channel_capacity(self, capacity: usize) -> Self
pub fn with_channel_capacity(self, capacity: usize) -> Self
Set the default channel capacity.
Sourcepub fn with_workers(self, workers: usize) -> Self
pub fn with_workers(self, workers: usize) -> Self
Set the worker count (M:N).